==> qmmp-0.9.2-1.00.tar.gz: qmmp-0.9.2/src/plugins/Input/mpc/translations/mpc_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Musepack 檔案</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="133"/>
        <source>About Musepack Audio Plugin</source>
        <translation>關於 Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation type="unfinished">Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation type="unfinished">kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation type="unfinished">KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/mpc/translations/mpc_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderMPCFactory</name>
    <message>
        <location filename="../decodermpcfactory.cpp" line="62"/>
        <source>Musepack Plugin</source>
        <translation>Musepack 外掛</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="64"/>
        <source>Musepack Files</source>
        <translation>Musepack 檔案</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="133"/>
        <source>About Musepack Audio Plugin</source>
        <translation>關於 Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="134"/>
        <source>Qmmp Musepack Audio Plugin</source>
        <translation>Qmmp Musepack 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decodermpcfactory.cpp" line="135"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>MPCMetaDataModel</name>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="46"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="47"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="48"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="49"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../mpcmetadatamodel.cpp" line="50"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>
